import pathlib
from pathlib import Path
from setuptools import setup
import os

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

if not os.path.exists(f'{str(Path.home())}/.cheatsheets/'):
    os.makedirs(f'{str(Path.home())}/.cheatsheets/')

setup(
    name="cheatsheets",
    version="0.0.1",
    description="Cheatsheets",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/Tlalocan/cheatsheets",
    author="Tlaloc-Es",
    author_email="",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["cheatsheets"],
    include_package_data=True,
    install_requires=["simple-term-menu", "pygments"],
    entry_points={
        "console_scripts": [
            "cheatsheets=cheatsheets.cheatsheets:main",
        ]
    },
)


from simple_term_menu import TerminalMenu
from pygments import formatters, highlight, lexers
from pygments.util import ClassNotFound
import json
import os
import re
from pathlib import Path

CHEAT_DIRECTORY = f'{str(Path.home())}/.cheatsheets/'


def preview_cheat(cheat):
    filepath = CHEAT_DIRECTORY+cheat
    with open(filepath, "r") as f:
        file_content = f.read()
    try:
        lexer = lexers.get_lexer_for_filename(filepath, stripnl=False, stripall=False)
    except ClassNotFound:
        lexer = lexers.get_lexer_by_name("text", stripnl=False, stripall=False)
    formatter = formatters.TerminalFormatter(bg="dark")  # dark or light
    highlighted_file_content = highlight(file_content, lexer, formatter)
    return highlighted_file_content


def list_cheats():
    return [file for file in os.listdir(CHEAT_DIRECTORY) if os.path.isfile(os.path.join(CHEAT_DIRECTORY, file))]


def execute_cheat(cheat):

    with open(CHEAT_DIRECTORY+cheat) as f:
        data = json.load(f)
    
    command = data['command']
    try:
        arg = re.search('<(.+?)>', command).group(1)
        while arg:
            arg_val = input(f'Insert value for arg: {arg}\n')
            command = command.replace(f'<{arg}>', arg_val, 1)
            arg = re.search('<(.+?)>', command).group(1)
            print(command+'\n')
    except Exception:
        pass

    os.system(command)


def main():
    cheats = list_cheats()

    if len(cheats) > 0:
        terminal_menu = TerminalMenu(cheats, preview_command=preview_cheat, preview_size=0.75)
        menu_entry_index = terminal_menu.show()
        execute_cheat(cheats[menu_entry_index])
    else:
        print("You don't have any cheat")

if __name__ == "__main__":
    main()